Django Perseus
==============

Builds a static version of your Django website.

Documentation about installing and usage can be found at [django-perseus.readthedocs.org](https://django-perseus.readthedocs.org)
